qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Qemu-devel] [PATCH v2] scripts/checkpatch.pl: Bug fix


From: Su Hang
Subject: [Qemu-devel] [PATCH v2] scripts/checkpatch.pl: Bug fix
Date: Tue, 3 Apr 2018 23:17:13 +0800

checkpatch.pl stops complaining about following pattern:
"""
do {
    //do somethins;
} while (conditions);
"""

One things need to be mentioned:
Becasue `if`, `while` and `for` check have been done in this
`if` block(Line: 2356), and this block contains following statement:
""" Line: 2379
$suppress_ifbraces{$ln + $offset} = 1;
"""
So the behind block may never run:
""" Line: 2415
if (!defined $suppress_ifbraces{$linenr - 1} &&
    $line =~ /\b(if|while|for|else)\b/ &&
    $line !~ /\#\s*if/ &&
    $line !~ /\#\s*else/) {
"""
I'm not sure, please give me some advice.

(Sorry, I don't know this patch should base on which commit,
 so I generate this patch based on
 commit:fb8446d94ec7a3dc0c3a7e7da672406476f075ac,
 I choose this by `git log -2 scripts/checkpath.pl`.
 Sincerely say sorry, if I have misunderstand any meaning.)

Signed-off-by: Su Hang <address@hidden>
---
 scripts/checkpatch.pl | 21 +++++++++++++++++----
 1 file changed, 17 insertions(+), 4 deletions(-)

diff --git a/scripts/checkpatch.pl b/scripts/checkpatch.pl
index a88af61ed4ee..d6f0747ba20a 100755
--- a/scripts/checkpatch.pl
+++ b/scripts/checkpatch.pl
@@ -2352,8 +2352,22 @@ sub process {
                        }
                }

-# check for missing bracing round if etc
-               if ($line =~ /(^.*)\bif\b/ && $line !~ /\#\s*if/) {
+# check for missing bracing around if etc
+               if ($line =~ /(^.*)\b(?:if|while|for)\b/ &&
+                       $line !~ /\#\s*if/) {
+                       my $allowed = 0;
+
+                       # Check the pre-context.
+                       if ($line =~ /(\}.*?)$/) {
+                               my $pre = $1;
+
+                               if ($line !~ /else/) {
+                                       print "APW: ALLOWED: pre<$pre> 
line<$line>\n"
+                                               if $dbg_adv_apw;
+                                       $allowed = 1;
+                               }
+                       }
+
                        my ($level, $endln, @chunks) =
                                ctx_statement_full($linenr, $realcnt, 1);
                         if ($dbg_adv_apw) {
@@ -2362,7 +2376,6 @@ sub process {
                                 if $#chunks >= 1;
                         }
                        if ($#chunks >= 0 && $level == 0) {
-                               my $allowed = 0;
                                my $seen = 0;
                                my $herectx = $here . "\n";
                                my $ln = $linenr - 1;
@@ -2406,7 +2419,7 @@ sub process {
                                             $allowed = 1;
                                        }
                                }
-                               if ($seen != ($#chunks + 1)) {
+                               if ($seen != ($#chunks + 1) && !$allowed) {
                                        ERROR("braces {} are necessary for all 
arms of this statement\n" . $herectx);
                                }
                        }
--
2.7.4




reply via email to

[Prev in Thread] Current Thread [Next in Thread]